itkwasm - itkwasm python documentation
Description: itkwasm: Python interface to itk-wasm WebAssembly modules. Submodules: itkwasm.pipeline_input, itkwasm.transform, itkwasm.float_types, itkwasm.pyodide, itkwasm.pipeline, itkwasm.binary_stream, itkw...

Hide navigation sidebar
Hide table of contents sidebar
Back to top
Edit this page
Toggle table of contents sidebar

# `itkwasm`

itkwasm: Python interface to itk-wasm WebAssembly modules.

## Submodules

- `itkwasm.pipeline_input`
- `itkwasm.transform`
- `itkwasm.float_types`
- `itkwasm.pyodide`
- `itkwasm.pipeline`
- `itkwasm.binary_stream`
- `itkwasm.mesh`
- `itkwasm.binary_file`
- `itkwasm.interface_types`
- `itkwasm.image`
- `itkwasm.text_file`
- `itkwasm.pipeline_output`
- `itkwasm.polydata`
- `itkwasm.pixel_types`
- `itkwasm.int_types`
- `itkwasm.text_stream`
- `itkwasm.environment_dispatch`
- `itkwasm.pointset`

## Package Contents

### Data

`__version__` |
`__all__` |

### API

itkwasm.__version__

  ‘1.0b97’

itkwasm.__all__

  [‘InterfaceTypes’, ‘Pipeline’, ‘PipelineInput’, ‘PipelineOutput’, ‘Image’, ‘ImageType’, ‘PointSet’, …